@@ -8,8 +8,8 @@ from dice_ml.utils import helpers
 from lightgbm import LGBMClassifier
 from sklearn import svm
 from sklearn.compose import ColumnTransformer
-from sklearn.datasets import (load_boston, load_breast_cancer, load_iris,
-                              make_classification)
+from sklearn.datasets import (fetch_california_housing, load_breast_cancer,
+                              load_iris, make_classification)
 from sklearn.ensemble import RandomForestClassifier, RandomForestRegressor
 from sklearn.linear_model import LogisticRegression
 from sklearn.model_selection import train_test_split
@@ -72,6 +72,15 @@ def create_iris_data():
     classes = iris.target_names
     X_train = pd.DataFrame(X_train, columns=feature_names)
     X_test = pd.DataFrame(X_test, columns=feature_names)
+
+    # create duplicate index
+    test_index_list = X_test.index.tolist()
+    test_index_list.append(test_index_list[0])
+    X_test = X_test.reindex(test_index_list)
+    y_test_list = y_test.tolist()
+    y_test_list.append(y_test[0])
+    y_test = np.array(y_test_list)
+
     return X_train, X_test, y_train, y_test, feature_names, classes
 
 
@@ -105,14 +114,15 @@ def create_binary_classification_dataset():
     return X_train, y_train, X_test, y_test, classes
 
 
-def create_boston_data():
-    # Import Boston housing dataset
-    boston = load_boston()
+def create_housing_data():
+    # Import California housing dataset
+    housing = fetch_california_housing()
     # Split data into train and test
-    X_train, X_test, y_train, y_validation = train_test_split(
-        boston.data, boston.target,
-        test_size=0.2, random_state=7)
-    return X_train, X_test, y_train, y_validation, boston.feature_names
+    x_train, x_test, y_train, y_test = train_test_split(housing.data,
+                                                        housing.target,
+                                                        test_size=0.2,
+                                                        random_state=7)
+    return x_train, x_test, y_train, y_test, housing.feature_names
 
 
 def create_adult_income_dataset():
