@@ -13,8 +13,9 @@ from responsibleai.exceptions import UserConfigValidationException
 from responsibleai.modelanalysis.model_analysis import ModelAnalysis
 
 from .common_utils import (create_binary_classification_dataset,
-                           create_cancer_data, create_iris_data,
-                           create_lightgbm_classifier)
+                           create_cancer_data, create_housing_data,
+                           create_iris_data, create_lightgbm_classifier,
+                           create_sklearn_random_forest_regressor)
 
 
 class TestModelAnalysisValidations:
@@ -234,10 +235,10 @@ class TestModelAnalysisValidations:
         X_train['target'] = y_train
         X_test['target'] = y_test
 
-        err_msg = ('INVALID-TASK-TYPE-WARNING: The regression model'
+        err_msg = ('The regression model'
                    'provided has a predict_proba function. '
                    'Please check the task_type.')
-        with pytest.warns(UserWarning, match=err_msg):
+        with pytest.raises(UserConfigValidationException, match=err_msg):
             ModelAnalysis(
                 model=model,
                 train=X_train,
@@ -424,18 +425,20 @@ class TestCounterfactualUserConfigValidations:
                 method='random')
 
     def test_desired_range_not_set(self):
-        X_train, y_train, X_test, y_test, _ = \
-            create_binary_classification_dataset()
+        X_train, X_test, y_train, y_test, feature_names = \
+            create_housing_data()
 
-        model = create_lightgbm_classifier(X_train, y_train)
-        X_train['target'] = y_train
-        X_test['target'] = y_test
+        model = create_sklearn_random_forest_regressor(X_train, y_train)
+        X_train = pd.DataFrame(X_train, columns=feature_names)
+        X_test = pd.DataFrame(X_test, columns=feature_names)
+        X_train['TARGET'] = y_train
+        X_test['TARGET'] = y_test
 
         model_analysis = ModelAnalysis(
             model=model,
             train=X_train,
             test=X_test,
-            target_column='target',
+            target_column='TARGET',
             task_type='regression')
         with pytest.raises(
                 UserConfigValidationException,
